module m1_esc(
	input                   clk25                       ,
    input                   key                         ,

	input                   mii_link_0                  ,
	input                   mii_rx_clk_0                ,
	input                   mii_rx_dv_0                 ,
	input       [3:0]       mii_rx_data_0               ,
	input                   mii_rx_err_0                ,
	output                  mii_tx_en_0                 ,
	output      [3:0]       mii_tx_data_0               ,
    output                  linkack_led_0               ,

	input                   mii_link_1                  ,
	input                   mii_rx_clk_1                ,
	input                   mii_rx_dv_1                 ,
	input       [3:0]       mii_rx_data_1               ,
	input                   mii_rx_err_1                ,
	output                  mii_tx_en_1                 ,
	output      [3:0]       mii_tx_data_1               ,
    output                  linkack_led_1               ,


    output                  phy1_clk                    ,
    output                  phy2_clk                    ,
    
    output  reg             phy1_rst_n                  ,
    output  reg             phy2_rst_n                  ,

	output                  mdc                         ,
	inout                   mdio                        ,


    output                  prom_clk                    ,
    inout                   prom_data                   ,
    output                  prom_loaded                 ,
    output                  A0                          ,
    output                  A1                          ,
    output                  A2                          ,

    output                  run_led                    


);

wire clk100;
wire lock;
wire rst_n;

wire phy_clk;

reg [14:0] cnt;

wire MCU_CLK;       //MCU 50MHz
wire sync0;
wire sync1;
wire irq;
wire NSS;
wire SCLK;
wire MOSI;
wire MISO;

wire 		HCLK				;
wire 		HRESETn				;
wire [31:0]	HADDR				;
wire [1:0]	HTRANS				;
wire 		HWRITE				;//1:wr,0:rd
wire [2:0]	HSIZE				;
wire [2:0]	HBURST				;
wire [31:0]	HWDATA		;
wire 		HSEL				;
wire [31:0]	HRDATA		;
wire 		HREADY				;
wire [1:0]	HRESP				;	


button u_button(
.out(rst_n),
.in(key),
.clk(clk25),
.rstn(1'b1)
);

Gowin_rPLL u_Gowin_rPLL(
        .clkout(clk100), //output clkout
        .lock(lock),
        .clkoutd(phy_clk),
        .clkin(clk25) //input clkin
    );
	
Gowin_rPLL_MCU u_Gowin_rPLL_MCU(
        .clkout(MCU_CLK), //output clkout
        .clkin(clk25) //input clkin
);

assign phy1_clk = phy_clk;
assign phy2_clk = phy_clk;


always@(posedge clk25 or negedge rst_n)begin
    if(!rst_n)
        cnt <= 10'd0;
    else if(lock && cnt < 15'd30000)
        cnt <= cnt + 1'b1;
end

always@(posedge clk25 or negedge rst_n)begin
    if(!rst_n)begin
        phy1_rst_n <= 1'b0;
        phy2_rst_n <= 1'b0;
    end
    else if(lock && (cnt == 15'd30000))begin
        phy1_rst_n <= 1'b1;
        phy2_rst_n <= 1'b1;
    end
end


assign A0 = 1'b0;
assign A1 = 1'b0;
assign A2 = 1'b0;

wire run_led_wire;

assign run_led = !run_led_wire;

wire mdi;
wire mdo;
wire mdoen;

assign mdi = mdio;
assign mdio = (!mdoen) ? mdo : 1'bz;

wire prom_data_in;
wire prom_data_out;
wire prom_data_oen;

assign prom_data_in = prom_data;
assign prom_data = (!prom_data_oen) ? prom_data_out : 1'bz;

 
IES_Top U_IES_Top(
    .clk100(clk100)                      ,
    .reset_n(rst_n)                     ,
	.mii_link_0(!mii_link_0)                  ,
	.mii_rx_clk_0(mii_rx_clk_0)                ,
	.mii_rx_dv_0(mii_rx_dv_0)                 ,
	.mii_rx_data_0(mii_rx_data_0)               ,
	.mii_rx_err_0(mii_rx_err_0)                ,
	.mii_tx_en_0(mii_tx_en_0)                 ,
	.mii_tx_data_0(mii_tx_data_0)               ,
    .mii_tx_shift_0(2'b00),
    .linkack_led_0(linkack_led_0)                   ,
	.mii_link_1(!mii_link_1)                  ,
	.mii_rx_clk_1(mii_rx_clk_1)                ,
	.mii_rx_dv_1(mii_rx_dv_1)                 ,
	.mii_rx_data_1(mii_rx_data_1)               ,
	.mii_rx_err_1(mii_rx_err_1)                ,
	.mii_tx_en_1(mii_tx_en_1)                 ,
	.mii_tx_data_1(mii_tx_data_1)               ,
    .mii_tx_shift_1(2'b00),
    .linkack_led_1(linkack_led_1)                   ,
	.mdc(mdc)                         ,
    .mdi(mdi),
    .mdo(mdo),
    .mdoen(mdoen),
	.phy_offset_vec(5'd0)              ,
    .prom_clk(prom_clk)                    ,
    .prom_data_in(prom_data_in),
    .prom_data_out(prom_data_out),
    .prom_data_oen(prom_data_oen),
    .prom_size(1'b1)                   ,
    .prom_loaded(prom_loaded)                 ,
	.irq(irq)                     ,
    .HCLK						(HCLK),
    .HRESETn					(HRESETn),
    .HADDR						(HADDR[15:0]),
    .HTRANS						(HTRANS),
    .HWRITE						(HWRITE),
    .HSIZE						(HSIZE),
    .HBURST						(HBURST),
    .HWDATA						(HWDATA),
    .HSEL						(HSEL),
    .HRDATA						(HRDATA),
    .HREADY						(HREADY),
    .HRESP						(HRESP),
	.pdi_emulation              (1'b0),
    .sync0(sync0)                       ,
    .sync1(sync1)                       ,
    .latch0(1'b0)                       ,
    .latch1(1'b0)                       ,
    .run_led(run_led_wire)

);

Gowin_EMPU_M1_template u_Gowin_EMPU_M1_template(
    .LOCKUP(),
    //.HALTED(),
	
    //GPIO,
    .GPIOIN({1'b0,(~sync1),(~sync0),irq}),
    //.GPIOOUT(),
	
//    .JTAG_3(),   //trstn
//    .JTAG_4(),   //NC
//    .JTAG_5(),   //tdi
//    .JTAG_6(),   //NC
//    .JTAG_7(JTAG_7),   //tms   |       swdio
//    .JTAG_8(),   //extFlash_sspi2_sio3/holdn
//    .JTAG_9(JTAG_9),   //tck   |       swclk
//    .JTAG_10(),  //extFlash_spi2_mosi/sio1
//    .JTAG_11(),  //NC    |       
//    .JTAG_12(),  //extFlash_spi2_sclk
//    .JTAG_13(),  //tdo   |       swo
//    .JTAG_14(),  //extFlash_spi2_miso/sio0
//    .JTAG_15(),  //srstn
//    .JTAG_16(),  //extFlash_spi2_cs
//    .JTAG_17(),  //NC
//    .JTAG_18(),  //extFlash_sspi2_sio2/WPn
//	
//    .UART0RXD(UART0RXD),
//    .UART0TXD(UART0TXD),
	
    //.MOSI(MOSI),
    //.MISO(MISO),
    //.SCLK(SCLK),
    //.NSS(NSS),

//wire 		HCLK				;
//wire 		HRESETn				;
//wire [15:0]	HADDR				;
//wire [1:0]	HTRANS				;
//wire 		HWRITE				;//1:wr,0:rd
//wire [2:0]	HSIZE				;
//wire [2:0]	HBURST				;
//wire [31:0]	HWDATA		;
//wire 		HSEL				;
//wire [31:0]	HRDATA		;
//wire 		HREADY				;
//wire [1:0]	HRESP				;	

	.AHB1HRDATA(HRDATA), //input [31:0] AHB1HRDATA
    .AHB1HREADYOUT(HREADY), //input AHB1HREADYOUT
    .AHB1HRESP(HRESP), //input [1:0] AHB1HRESP
    .AHB1HTRANS(HTRANS), //output [1:0] AHB1HTRANS
    .AHB1HBURST(HBURST), //output [2:0] AHB1HBURST
    .AHB1HPROT(), //output [3:0] AHB1HPROT
    .AHB1HSIZE(HSIZE), //output [2:0] AHB1HSIZE
    .AHB1HWRITE(HWRITE), //output AHB1HWRITE
    .AHB1HREADYMUX(), //output AHB1HREADYMUX
    .AHB1HMASTER(), //output [3:0] AHB1HMASTER
    .AHB1HMASTLOCK(), //output AHB1HMASTLOCK
    .AHB1HADDR(HADDR), //output [31:0] AHB1HADDR
    .AHB1HWDATA(HWDATA), //output [31:0] AHB1HWDATA
    .AHB1HSEL(HSEL), //output AHB1HSEL
    .AHB1HCLK(HCLK), //output AHB1HCLK
    .AHB1HRESET(HRESETn), //output AHB1HRESET


    .HCLK(MCU_CLK),
    .hwRstn(rst_n)
);


endmodule
